@@ -28,7 +28,7 @@ def batch_records(
     batches, remaining = [], records
     logger.info(f"MAX BATCH || {max_batch_size}  MIN COMMON DIM || {min_common_dimensions}")
     while len(remaining) > 0:
-        logger.info(remaining)
+        logger.info(len(remaining))
         batch, remaining = _batch_records_helper(
             remaining, max_batch_size, min_common_dimensions
         )
